local Addon = LibStub("AceAddon-3.0"):GetAddon("Langoustine")
local module = Addon:NewModule("Options")
local L = LibStub("AceLocale-3.0"):GetLocale("LangoustineOptions")
local Sink = LibStub("LibSink-2.0")
local Media = LibStub("LibSharedMedia-3.0")
local Tanks = Addon:GetModule("Tanks")

local options = {
	type = "group",
	name = L["Langoustine"],
	args = {
	}
}

function module:OnInitialize()
	self.db = Addon.db.profile
	self:SetupLootOptions()
	self:SetupAutoPromote()
	self:SetupInviteOptions()
	self:SetupTankOptions()
	options.args.Profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(Addon.db)
	options.args.Profile.order=99
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Langoustine", options)
	Addon.OptionFrame = true
	--Addon.OptionFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Langoustine", "General")
end

function module:SetupTankOptions()
	local sinkTable = Addon:GetSinkAce3OptionsDataTable()
	options.args.Tanks = {
		name = L["Tank Options"],
		type = "group",
		order = 9,
		args = {
			core = {
				type = "group",
				name = L["Windows"],
				guiInline = true,
				order = 1,
				args = {
					mt = { 
						type = "toggle", name = L["Tank"], 
						get = function() return module.db.TankShow end, set = function(info, v) module.db.TankShow = v end, desc = L["Tank window."],
						order = 1,
					},
					mtt = { 
						type = "toggle", name = L["Target"], 
						get = function() return module.db.TankShowTarget end, set = function(info, v) module.db.TankShowTarget = v end, desc = L["Target window."],
						order =2
					},
					mttt = { 
						type = "toggle", name = L["Target of Target"], 
						get = function() return module.db.TankShowTargetTarget end, set = function(info, v) module.db.TankShowTargetTarget = v end, desc = L["Target of Target window."],
						order = 3,
					},
					maxTanks = { 
						type = 'range', name = L["Max Tanks"], desc = L["Maximum number of tanks"], min = 0, max = 10, step = 1,
						get = function() return module.db.MaxTanks end, set = function(info,v) module.db.MaxTanks = v end, order = 4
					},
					notify = { 
						type = "toggle", name = L["Notify on Death"], desc = L["Generate messages about the Tank death."],
						get = function() return module.db.NotifyMTDeath end, set = function(info,v) module.db.NotifyMTDeath = v end,
						order = 5
					},
					notSink = sinkTable,
				}
			},
			ui = {
				type = "group",
				name = L["Look and Feel"],
				guiInline = true,
				order = 2,
				args = {
					color = { type = "description", name = "color dummy"},
					width = {type = "description", name = "width dummy"},
					scale = { type = "description", name = "scale dummy"},
					height = { type = "description", name = "height dummy"},
					statusBar = { 
						type = "select", 
						name = L["Health bar texture"],
						desc = L["Texture to use for the window health bar."],
						values = Media:HashTable("statusbar"),
						dialogControl = "LSM30_Statusbar",
						get = function() return module.db.TankOptions.barTexture end,
						set = function(info, v) module.db.TankOptions.barTexture =v; Tanks:RestyleWindows() end,
					},
					growth = { type = "description", name = "growth dummy"},
					icon = { type = "description", name = "icon dummy"},
					targetAnchor = { type = "description", name = "tanchor dummy"},
					totAnchor = { type = "description", name = "totanchor dummy"},
					clickCast = { type = "description", name = "clique dummy"},
					highlight = { type = "description", name = "highlight dummy"},
					
				}
			}
		}
	}
	options.args.Tanks.args.core.args.notSink.order=99
	options.args.Tanks.args.core.args.notSink.guiInline=true
	options.args.Tanks.args.core.args.notSink.name=L["Notification output"]
end

function module:SetupInviteOptions()
	options.args.Invites = {
		name = L["Invitations"],
		order = 3,
		type = "group",
		args = {
			whisper = {
				type = "group",
				name = L["Whisper Options"],
				guiInline = true,
				args = {
					checkbox = {
						name = L["Enabled"],
						desc = L["Enable whisper invites."],
						type = "toggle",
						set = function(info,v) module.db.WhisperInvite = v end,
						get = function() return module.db.WhisperInvite end,
						order = 1,
					},
					trigger = {
						name = L["Whisper Trigger"],
						desc = L["This is the keyword that will auto invite players who whisper you."],
						type = "input",
						set = function(info, k) module.db.WhisperInviteTriggger = k end,
						get = function() return module.db.WhisperInviteTriggger end,
						disabled = function() return not module.db.WhisperInvite end,
						order = 2,
					}
				}
			}
		}
	}
end

function module:SetupAutoPromote()
	local pList = {}
	
	options.args.Promotes = {
		name = L["Auto Promotes"],
		order =1,
		type = "group",
		args = {
			checkbox = {
				name = L["Enabled"],
				desc = L["Enable auto promotions."],
				type = "toggle",
				set = function(info,v) module.db.AutoPromoteEnabled = v end,
				get = function() return module.db.AutoPromoteEnabled end,
				order = 1,
			},
			clearList = {
				name = L["Clear all promotes"],
				type = "execute",
				func = function() wipe(module.db.AutoPromote) end,
				confirm = true,
				confirmText = L["Are you sure you wish to delete all promotions?"],
				order = 50,
			},
			rankGroup = {
				type = "group",
				name = L["Auto Promotions"],
				guiInline = true,
				disabled = function() return not module.db.AutoPromoteEnabled end,
				args = {
					byRank = {
						name = L["Promote by Rank"],
						type = 'select',
						desc = L["Promote any raid member who is this rank for higher."],
						values = function() return Addon.granks end,
						set = function(info,v) module.db.AutoPromoteRank = v end,
						get = function() return module.db.AutoPromoteRank end,
						order = 2,
					},
					byNameInput = {
						name = L["Add Player"],
						type = "input",
						set = function(info, k) module.db.AutoPromote[k] = true end,
						order = 3,
					},
					byName = {
						name = L["Current promotes"],
						type = 'multiselect',
						desc = L["Current list of promotions."],
						values = function() 
							wipe(pList)
							for k,v in pairs(module.db.AutoPromote) do
								pList[k] = k
							end
							return pList
						end,
						set = function(info, k, v) 
							module.db.AutoPromote[k] = v 
							if not v then
								module.db.AutoPromote[k] = nil
							end
						end,
						get = function(info, k) return module.db.AutoPromote[k] end,
					}
				},
			},
		}
	}
end

function module:SetupLootOptions()
	local qList = {}
	qList["2"] = ITEM_QUALITY_COLORS[2].hex..ITEM_QUALITY2_DESC.."|r"
	qList["3"] = ITEM_QUALITY_COLORS[3].hex..ITEM_QUALITY3_DESC.."|r"
	qList["4"] = ITEM_QUALITY_COLORS[4].hex..ITEM_QUALITY4_DESC.."|r"
	qList["5"] = ITEM_QUALITY_COLORS[5].hex..ITEM_QUALITY5_DESC.."|r"
	qList["6"] = ITEM_QUALITY_COLORS[6].hex..ITEM_QUALITY6_DESC.."|r"
	
	options.args.Loot = {
		order = 2,
		name = L["Auto Loot"],
		type = "group",
		args = {
			checkbox = {
				name = L["Enabled"],
				desc = L["Enable auto loot configuration."],
				type = "toggle",
				set = function(info,v) module.db.AutoLootEnabled = v end,
				get = function() return module.db.AutoLootEnabled end,
			},
			lootgroup = {
				type = "group",
				guiInline = true,
				name = L["Loot options"],
				disabled = function() return not module.db.AutoLootEnabled end,
				args = {
					method = {
						type = 'select',
						name = LOOT_METHOD,
						values = { ["group"] = LOOT_GROUP_LOOT, ["freeforall"] = LOOT_FREE_FOR_ALL, ["master"] = LOOT_MASTER_LOOTER, ["needbeforegreed"] = LOOT_NEED_BEFORE_GREED, ["roundrobin"] = LOOT_ROUND_ROBIN},
						get = function() return module.db.AutoLoot.method end,
						set = function(info, v) 
							module.db.AutoLoot.method = v 
							module.db.SetLoot = false
							if v == "master" then
								module.db.SetML = false
							end
							Addon:RaidCheck()
						end,
					},
					threshold = {
						type = 'select',
						name = LOOT_THRESHOLD,
						values = qList,
						get = function() return module.db.AutoLoot.threshold end,
						set = function(info, v) 
							module.db.AutoLoot.threshold = v 
							module.db.SetLoot = false
							Addon:RaidCheck()
						end,
					},
					master = {
						type = "input",
						name = LOOT_PROMOTE,
						set = function(info, v) 
							if v ~= module.db.AutoLoot.looter then
								module.db.AutoLoot.looter = v 
								module.db.SetML = false
								Addon:RaidCheck()
							end
						end,
						get = function() return module.db.AutoLoot.looter end,
					}
				}
			}
		}
	}
end